@@ -10,8 +10,6 @@ from sqlglot.optimizer.canonicalize import canonicalize
 from sqlglot.optimizer.eliminate_ctes import eliminate_ctes
 from sqlglot.optimizer.eliminate_joins import eliminate_joins
 from sqlglot.optimizer.eliminate_subqueries import eliminate_subqueries
-from sqlglot.optimizer.expand_laterals import expand_laterals
-from sqlglot.optimizer.expand_multi_table_selects import expand_multi_table_selects
 from sqlglot.optimizer.isolate_table_selects import isolate_table_selects
 from sqlglot.optimizer.lower_identities import lower_identities
 from sqlglot.optimizer.merge_subqueries import merge_subqueries
@@ -30,12 +28,10 @@ RULES = (
     qualify_tables,
     isolate_table_selects,
     qualify_columns,
-    expand_laterals,
     pushdown_projections,
     validate_qualify_columns,
     normalize,
     unnest_subqueries,
-    expand_multi_table_selects,
     pushdown_predicates,
     optimize_joins,
     eliminate_subqueries,
@@ -83,6 +79,7 @@ def optimize(
     schema = ensure_schema(schema or sqlglot.schema, dialect=dialect)
     possible_kwargs = {"db": db, "catalog": catalog, "schema": schema, **kwargs}
     expression = exp.maybe_parse(expression, dialect=dialect, copy=True)
+
     for rule in rules:
         # Find any additional rule parameters, beyond `expression`
         rule_params = rule.__code__.co_varnames
@@ -90,4 +87,5 @@ def optimize(
             param: possible_kwargs[param] for param in rule_params if param in possible_kwargs
         }
         expression = rule(expression, **rule_kwargs)
+
     return expression
