@@ -83,6 +83,7 @@ class Scope:
         self._columns = None
         self._external_columns = None
         self._join_hints = None
+        self._pivots = None
 
     def branch(self, expression, scope_type, chain_sources=None, **kwargs):
         """Branch from the current scope to a new, inner scope"""
@@ -261,12 +262,14 @@ class Scope:
 
             self._columns = []
             for column in columns + external_columns:
-                ancestor = column.find_ancestor(exp.Qualify, exp.Order, exp.Having, exp.Hint)
+                ancestor = column.find_ancestor(
+                    exp.Select, exp.Qualify, exp.Order, exp.Having, exp.Hint
+                )
                 if (
                     not ancestor
-                    # Window functions can have an ORDER BY clause
-                    or not isinstance(ancestor.parent, exp.Select)
                     or column.table
+                    or isinstance(ancestor, exp.Select)
+                    or (isinstance(ancestor, exp.Order) and isinstance(ancestor.parent, exp.Window))
                     or (column.name not in named_selects and not isinstance(ancestor, exp.Hint))
                 ):
                     self._columns.append(column)
@@ -370,6 +373,17 @@ class Scope:
             return []
         return self._join_hints
 
+    @property
+    def pivots(self):
+        if not self._pivots:
+            self._pivots = [
+                pivot
+                for node in self.tables + self.derived_tables
+                for pivot in node.args.get("pivots") or []
+            ]
+
+        return self._pivots
+
     def source_columns(self, source_name):
         """
         Get all columns in the current scope for a particular source.
@@ -510,6 +524,9 @@ def _traverse_scope(scope):
         yield from _traverse_union(scope)
     elif isinstance(scope.expression, exp.Subquery):
         yield from _traverse_subqueries(scope)
+    elif isinstance(scope.expression, exp.Table):
+        # This case corresponds to a "join construct", i.e. (tbl1 JOIN tbl2 ON ..)
+        yield from _traverse_tables(scope)
     elif isinstance(scope.expression, exp.UDTF):
         pass
     else:
@@ -582,11 +599,14 @@ def _traverse_tables(scope):
     expressions = []
     from_ = scope.expression.args.get("from")
     if from_:
-        expressions.extend(from_.expressions)
+        expressions.append(from_.this)
 
     for join in scope.expression.args.get("joins") or []:
         expressions.append(join.this)
 
+    if isinstance(scope.expression, exp.Table):
+        expressions.append(scope.expression)
+
     expressions.extend(scope.expression.args.get("laterals") or [])
 
     for expression in expressions:
@@ -595,8 +615,13 @@ def _traverse_tables(scope):
             source_name = expression.alias_or_name
 
             if table_name in scope.sources:
-                # This is a reference to a parent source (e.g. a CTE), not an actual table.
-                sources[source_name] = scope.sources[table_name]
+                # This is a reference to a parent source (e.g. a CTE), not an actual table, unless
+                # it is pivoted, because then we get back a new table and hence a new source.
+                pivots = expression.args.get("pivots")
+                if pivots:
+                    sources[pivots[0].alias] = expression
+                else:
+                    sources[source_name] = scope.sources[table_name]
             elif source_name in sources:
                 sources[find_new_name(sources, table_name)] = expression
             else:
