@@ -63,16 +63,17 @@ def eliminate_distinct_on(expression: exp.Expression) -> exp.Expression:
         distinct_cols = expression.args["distinct"].pop().args["on"].expressions
         outer_selects = expression.selects
         row_number = find_new_name(expression.named_selects, "_row_number")
-        window = exp.Window(
-            this=exp.RowNumber(),
-            partition_by=distinct_cols,
-        )
+        window = exp.Window(this=exp.RowNumber(), partition_by=distinct_cols)
         order = expression.args.get("order")
+
         if order:
             window.set("order", order.pop().copy())
+
         window = exp.alias_(window, row_number)
         expression.select(window, copy=False)
+
         return exp.select(*outer_selects).from_(expression.subquery()).where(f'"{row_number}" = 1')
+
     return expression
 
 
@@ -93,7 +94,7 @@ def eliminate_qualify(expression: exp.Expression) -> exp.Expression:
         for select in expression.selects:
             if not select.alias_or_name:
                 alias = find_new_name(taken, "_c")
-                select.replace(exp.alias_(select.copy(), alias))
+                select.replace(exp.alias_(select, alias))
                 taken.add(alias)
 
         outer_selects = exp.select(*[select.alias_or_name for select in expression.selects])
@@ -102,8 +103,9 @@ def eliminate_qualify(expression: exp.Expression) -> exp.Expression:
         for expr in qualify_filters.find_all((exp.Window, exp.Column)):
             if isinstance(expr, exp.Window):
                 alias = find_new_name(expression.named_selects, "_w")
-                expression.select(exp.alias_(expr.copy(), alias), copy=False)
+                expression.select(exp.alias_(expr, alias), copy=False)
                 column = exp.column(alias)
+
                 if isinstance(expr.parent, exp.Qualify):
                     qualify_filters = column
                 else:
@@ -121,20 +123,10 @@ def remove_precision_parameterized_types(expression: exp.Expression) -> exp.Expr
     Some dialects only allow the precision for parameterized types to be defined in the DDL and not in
     other expressions. This transforms removes the precision from parameterized types in expressions.
     """
-    return expression.transform(
-        lambda node: exp.DataType(
-            **{
-                **node.args,
-                "expressions": [
-                    node_expression
-                    for node_expression in node.expressions
-                    if isinstance(node_expression, exp.DataType)
-                ],
-            }
-        )
-        if isinstance(node, exp.DataType)
-        else node,
-    )
+    for node in expression.find_all(exp.DataType):
+        node.set("expressions", [e for e in node.expressions if isinstance(e, exp.DataType)])
+
+    return expression
 
 
 def unnest_to_explode(expression: exp.Expression) -> exp.Expression:
@@ -158,6 +150,7 @@ def unnest_to_explode(expression: exp.Expression) -> exp.Expression:
                             alias=exp.TableAlias(this=alias.this, columns=[column]),  # type: ignore
                         ),
                     )
+
     return expression
 
 
@@ -237,6 +230,20 @@ def remove_target_from_merge(expression: exp.Expression) -> exp.Expression:
                 else node,
                 copy=False,
             )
+
+    return expression
+
+
+def remove_within_group_for_percentiles(expression: exp.Expression) -> exp.Expression:
+    if (
+        isinstance(expression, exp.WithinGroup)
+        and isinstance(expression.this, (exp.PercentileCont, exp.PercentileDisc))
+        and isinstance(expression.expression, exp.Order)
+    ):
+        quantile = expression.this.this
+        input_value = t.cast(exp.Ordered, expression.find(exp.Ordered)).this
+        return expression.replace(exp.ApproxQuantile(this=input_value, quantile=quantile))
+
     return expression
 
 
@@ -245,7 +252,8 @@ def preprocess(
 ) -> t.Callable[[Generator, exp.Expression], str]:
     """
     Creates a new transform by chaining a sequence of transformations and converts the resulting
-    expression to SQL, using an appropriate `Generator.TRANSFORMS` function.
+    expression to SQL, using either the "_sql" method corresponding to the resulting expression,
+    or the appropriate `Generator.TRANSFORMS` function (when applicable -- see below).
 
     Args:
         transforms: sequence of transform functions. These will be called in order.
@@ -255,17 +263,28 @@ def preprocess(
     """
 
     def _to_sql(self, expression: exp.Expression) -> str:
+        expression_type = type(expression)
+
         expression = transforms[0](expression.copy())
         for t in transforms[1:]:
             expression = t(expression)
-        return getattr(self, expression.key + "_sql")(expression)
+
+        _sql_handler = getattr(self, expression.key + "_sql", None)
+        if _sql_handler:
+            return _sql_handler(expression)
+
+        transforms_handler = self.TRANSFORMS.get(type(expression))
+        if transforms_handler:
+            # Ensures we don't enter an infinite loop. This can happen when the original expression
+            # has the same type as the final expression and there's no _sql method available for it,
+            # because then it'd re-enter _to_sql.
+            if expression_type is type(expression):
+                raise ValueError(
+                    f"Expression type {expression.__class__.__name__} requires a _sql method in order to be transformed."
+                )
+
+            return transforms_handler(self, expression)
+
+        raise ValueError(f"Unsupported expression type {expression.__class__.__name__}.")
 
     return _to_sql
-
-
-UNALIAS_GROUP = {exp.Group: preprocess([unalias_group])}
-ELIMINATE_DISTINCT_ON = {exp.Select: preprocess([eliminate_distinct_on])}
-ELIMINATE_QUALIFY = {exp.Select: preprocess([eliminate_qualify])}
-REMOVE_PRECISION_PARAMETERIZED_TYPES = {
-    exp.Cast: preprocess([remove_precision_parameterized_types])
-}
